;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xc1b6137190638d4d97e64f9784003d55 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xe6f4df1e87e4db3d54eb2b89c10b6c72 . "./code.cg2js/cg-printing.fasl")
(#x55bc520b26905656aadf2423c54ace5f . "./code.cg2js/cg-caret.fasl")
(#xe7bd811ebd355533c21ebe44cc072130 . "./code.cg2js/cg-item-list.fasl")
(#x4ce47d19beefd69451593404ed1575ec . "./code.cg2js/cg-progress-indicator.fasl")
(#x98a4c1d83552bd6604b5a971b1f47d31 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xc9b3241bd5a18f9e65b2db6644205649 . "./code.cg2js/cg-outline.fasl")
(#x9d39df2510692f73d64cc08414540210 . "./code.cg2js/cg-palette.fasl")
(#x5797197ada111291b11b8f9875c1dc4a . "./code.cg2js/cg-selected-object.fasl")
(#x8dae270a08075b77b9827336d2ff87a7 . "./code.cg2js/cg-status-bar.fasl")
(#x8c6e58c8fd27b199a82d6281b5d58d1a . "./code.cg2js/cg-wrap-string.fasl")
(#x740d70381cbc55640b5cbdba4610fa1d . "./code.cg2js/cg-fill-texture.fasl")
(#xea10c12b6897a243c7864b17a6f59d22 . "./code.cg2js/cg-layout.fasl")
(#x96d5821363637643ee69b1575405486e . "./code.cg2js/cg-timer.fasl")
(#xcee3cbf4003cb0569cc9e06518c5588c . "./code.cg2js/cg-dialog-item.fasl")
(#xf839f8c16d03567079ccfcd6a33e9933 . "./code.cg2js/cg-button.fasl")
(#x571366b16c95a8692c3a31a6cada533e . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xd4fdf73914f9527a12e5c132a27471f0 . "./code.cg2js/cg-tray.fasl")
(#x136dbde1aa6896ed90bface7c7718d54 . "./code.cg2js/cg-plot-widget.fasl")
(#x3f3c0a440fb7d4e7dd0c7d5a95ea6e27 . "./code.cg2js/cg-pixmap.fasl")
(#xc7615453f357672e1b398126689a5ca8 . "./code.cg2js/cg-font-dialog.fasl")
(#x0542d123b069ddbe7b80d455a9ed667a . "./code.cg2js/cg-os-widget.fasl")
(#xbf811b9ba3cddea231168e5434704996 . "./code.cg2js/cg-text-or-combo.fasl")
(#xe6d488b5e57b90c4c9433d9d57462d24 . "./code.cg2js/cg-trackbar.fasl")
(#x0c1b4694bf4ab20e771f4724791eef6b . "./code.cg2js/cg-up-down-control.fasl")
(#xd1c2b4d6a966efd0fcb08013039f8865 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xd97358519973af9e46c384d9d8391494 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x627c17062464bb459db1f5d387396898 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x0b54e38e75703c10848268e485e09bed . "./code.cg2js/cg-bitmap-stream.fasl")
(#xa3fe8f1ff13e1ace121f8a2fa7d4a1de . "./code.cg2js/cg-chart-widget.fasl")
(#x0259007fbfd9382417158df21b68e401 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xf6a10098896d1511351ded5200d469e1 . "./code.cg2js/cg-group-box.fasl")
(#x9c70a4eb0826e819e849b533ca2c7d47 . "./code.cg2js/cg-static-text.fasl")
(#x2489a61f7b16518d5498a4868bee891e . "./code.cg2js/cg-class-slot-grid.fasl")
(#x482047b8c304ff6038a0f9bb4bac0a3d . "./code.cg2js/cg-color-dialog.fasl")
(#x117a2a314ead3e13994f38070fef8ab7 . "./code.cg2js/cg-intersect.fasl")
(#x60ee338d60f64e3073df754e1c532563 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xdbec66d39f2c056ba06644bad89996a7 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x7fc281c4431da56a48f93c586b0b4901 . "./code.cg2js/cg-html-dialog.fasl")
(#xe44cedfbb37bd3527eaf237e9121301e . "./code.cg2js/cg-lettered-menu.fasl")
(#x0fee421bf23594fcb89b55a1c823d876 . "./code.cg2js/cg-class-grid.fasl")
(#x2e4426e45f302039a01bdef778fb4008 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x4f291b3776a2c62abe9da70e62312ba7 . "./code.cg2js/cg-calendar.fasl")
(#x827a6647e8a8a62d6a5739c7e502ada7 . "./code.cg2js/cg-editable-text.fasl")
(#x69aadb715e2f75ef00dcee7af0993b66 . "./code.cg2js/cg-property.fasl")
(#x71dfd32f128a3ab9df04a1a0ad11d834 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x903fede59cb09c0ad71530ac87dfedf7 . "./code.cg2js/cg-grid-widget.fasl")
(#x1efe53ad4cefc0c5643597093094b55b . "./code.cg2js/cg-paren-matching.fasl")
(#x660abfee1e8802e4318d81f39fd865d5 . "./code.cg2js/cg-dev.fasl")
(#x59e59030c31f8ad606af64d5f8eb1a89 . "./code.cg2js/cg-drawable.fasl")
(#xbb4c399e8540d9fe0d1e5e9dcc3b0f08 . "./code.cg2js/cg-curve.fasl")
(#xe2bacb527718a36bfcc3622e4969033f . "./code.cg2js/cg-lisp-widget.fasl")
(#xbb989861600650cf664c1454233cc8cc . "./code.cg2js/cg-dde-utils.fasl")
(#x1719349570af3fdbd76d6da171cf047c . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xfa9f13ed584d62cd6e46493b1d727a53 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xcc88c853ad2b2e05ad64c7140662c05e . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xab1e798eb1f910078a0b05f63aabb505 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xe6fdd3ec73aec2eb60e523fca6cadb38 . "./code.cg2js/cg-lamp.fasl")
(#x87065394b5474b37cfebb4e6aca48561 . "./code.cg2js/cg-common-control.fasl")
(#x1592ad2316792d9dd367206b94a7a3ab . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x9363e77129ea65120124a37ec30bbaa8 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xd56cffced122372f406221ddca9ede8c . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xd6c722212f63c237942b6a039415d2a9 . "./code.cg2js/cg-project-window.fasl")
(#xff43ce1e57d230a684b4a85c94539025 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x5346d4612ba66b7f68ef7df0dd544e06 . "./code.cg2js/cg-class-support.fasl")
(#xb82412cafba07e936b110e121edbb160 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xd533ac0c08d8d68160d5077922612d16 . "./code.cg2js/cg-yes-no-list.fasl")
(#xfadb7fd2000de6a9721aa13e0086539d . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x7948aaab287cfa0215b56787e48574ac . "./code.cg2js/cg-string-dialog.fasl")
(#xba02e2a1f4e467a9107c77cc62cacbee . "./code.cg2js/cg-menu-tooltip.fasl")
(#x88eb0f2e0397834dd7968d5b057b35d9 . "./code.cg2js/cg-dropping-outline.fasl")
(#xb8d61286d896ac75fa0f674a2b992eb1 . "./code.cg2js/cg.fasl")
(#xab379cf17997fac5eacce5ee15a351ce . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x016349df18b5900aa783f4253fa34703 . "./code.cg2js/cg-scaling-stream.fasl")
(#xa826dbac785f487b19f3c59cced424c5 . "./code.cg2js/cg-yes-no-string.fasl")
(#x25057f0ccbeedef5eb2f6aa201136579 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x71b98acbee64db9702278836bceb9997 . "./code.cg2js/cg-web-browser.fasl")
(#xf8d8952a573383a59bf862a905d11bc9 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xea478c965a1e377a3ee22b6ddaea608f . "./code.cg2js/cg-drag-and-drop.fasl")
(#x2c8653d31a407073712dce592036507f . "./code.cg2js/cg-message-dialog.fasl")
(#x2f6632d8aa6fb31d7476040c5c891af3 . "./code.cg2js/cg-comtab.fasl")
(#x98dcfc9522dcfba6f3889c626d1d6715 . "./code.cg2js/cg-base.fasl")
(#x52eddb7f3a33000591cc55ee8763a2de . "./code.cg2js/cg-pixmap-widget.fasl")
(#xa6295f0bdf67b843e853a2774bce23e8 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x7dc788203cc24d315c291c907e414af8 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x074ab3075f5c615fbfb52ae18f8cc0ce . "./code.cg2js/cg-utility-dialog.fasl")
(#x5eb06c0e6c90572823fcdf2ffd87c04b . "./code.cg2js/cg-object-editor.fasl")
(#xa770b562384f806e5a9694e59317334e . "./code.cg2js/cg-edit-in-place.fasl")
(#xd2a0b58e9d4ce6eeb0037ff246753533 . "./code.cg2js/cg-radio-button.fasl")
(#x83b44cb1e7395564a2c87f3809b0ca55 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x893e598a606d762014211104d956a5f1 . "./code.cg2js/cg-nodes.fasl")
(#x8bb91e6e46a2c64f80d1f363e0d111d2 . "./code.cg2js/cg-get-position.fasl")
(#x08f0114a46467d1e9c50982f0068bf5f . "./code.cg2js/cg-directory-dialog.fasl")
(#xefd841efcb34677ee072436966587385 . "./code.cg2js/cg-lisp-text.fasl")
(#x12442e0e73a80a6d81e117be220884a1 . "./code.cg2js/cg-combo-box.fasl")
(#xf3d90e4ce2bea0d70bf89a2cd4cd7fe7 . "./code.cg2js/cg-text-widget.fasl")
(#x1578d75d64899e98c40c207f48704044 . "./code.cg2js/cg-list-view.fasl")
(#x59a97077f52dee7ca8b0329e7a741cad . "./code.cg2js/cg-header-control.fasl")
(#xafefc96b2f71a9094a3693c73ce10641 . "./code.cg2js/cg-graphics-context.fasl")
(#x7b00f5886cb598bf081ab35ce36140d7 . "./code.cg2js/cg-get-pixmap.fasl")
(#x66661a48a258593b15974961aecc9f1b . "./code.cg2js/cg-menu.fasl")
(#xd87fab0283a3092550cbf9c84031dcc8 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x0779a7f584eca1ad311ebf516dd6ed8d . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x42d9867910bc4f2fc2bdb4197792caba . "./code.cg2js/cg-tooltip.fasl")
(#xe9972e292fd13ff97d938bf4c3f2ca01 . "./code.cg2js/cg-html-widget.fasl")
(#x81756f1420e5a8f3c61dcd917d7f4b6a . "./code.cg2js/cg-choice-list.fasl")
(#xcea0a2330ac35d779fe4b679f1174327 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xfda88eb5ca314f7f5f566ef9e3e336bd . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xda496ecfa1631d03b3b23039f542f79c . "./code.cg2js/cg-icon.fasl")
(#x9905bc168dd6f9b51ca4990703a0341e . "./code.cg2js/cg-acache.fasl")
(#x3f2de2a3a7dc0bafa2fd9c7f74cc3215 . "./code.cg2js/cg-template-string.fasl")
(#xc0d9a2d072d89b3341bbdea7482c4dc0 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x1beb3ef7c8368fbde52df3df2d97270d . "./code.cg2js/cg-toggling-widget.fasl")
(#xd32d9cf1a4ca9c0c50642ebed8e9a83b . "./code.cg2js/cg-tab-control.fasl")
(#x2b4c576c310349bc3d138e51fe3c2683 . "./code.cg2js/cg-split-bar.fasl")
(#x09302f35a55f2505e7101279a281a151 . "./code.cg2js/cg-picture-widget.fasl")
(#x05aaa30498b8feadb61e733c48b4f28a . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x6d88706a2822d95e73bf7d733331203d . "./code.cg2js/cg-choose-printer.fasl")
(#x01be8a548d5bd59d57ac99b310607fe7 . "./code.cg2js/cg-os-window.fasl")
(#x76da3c7e0dd987b67a0dc84e7eafafe5 . "./code.cg2js/cg-scroll-bar.fasl")
(#x7f6fbd9bea8dcf37217dcea2c73b9816 . "./code.cg2js/cg-clipboard.fasl")
(#x13d3b569df1b985cadd894c5cb9954d0 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xaeead2700d957b60d72f589ddb00a223 . "./code.cg2js/cg-hotspot.fasl")
(#xacd2d641eaf0e231b75691dbb79b0e58 . "./code.cg2js/cg-rich-edit.fasl")
(#xf057c6ea6fa8e0cbee5a939c4e4937ae . "./code.cg2js/cg-check-box.fasl")
(#x4ed97dfa80a7c6fa3168190c52901c53 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x9aaf0940cf3d4ebc121b1c0c6d80d6dc . "./code.cg2js/cg-file-dialog.fasl")
(#x6389fe5643d0298a6de9f27136ca3d5f . "./code.cg2js/cg-toolbar.fasl")
(#x9255fa5562b6dbf565eab617fc794d6a . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x044e37b5e832c046e7388a67823a1f6c . "./code.cg2js/cg-chart-or-plot.fasl")
(#x283ac5a4886d2a4b629b7180e47e71f8 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x334c4994ded5de53f92b595b974e37de . "./code.idejs/ide-project.fasl")
(#x5de7ad3138ca64de30aea4b40eef6ec4 . "./code.idejs/ide-intro.fasl")
(#x1b13a556817ad3b6b2e020381067c88d . "./code.idejs/ide-find-in-files.fasl")
(#xe4acedf4e17f3cb2b18b8cfea369c15e . "./code.idejs/ide-grapher.fasl")
(#x3b9533a0038bf80d7e911b2e377b8927 . "./code.idejs/ide-inspector.fasl")
(#xfdbd43be6de70890dc2eb151b96e785b . "./code.idejs/ide-editor.fasl")
(#x7a89cd057f6868f6ca219626688fcebf . "./code.idejs/ide-window-list.fasl")
(#x39d4624bfd10daeee4aa8fc95086b6d8 . "./code.idejs/ide-process-browser.fasl")
(#xa1fc1c26c0d49b98e1016e6f1bbb1348 . "./code.idejs/ide-patch-dialog.fasl")
(#x572ca4c01e852ac5ef0bc6900ade21a1 . "./code.idejs/ide-class-grapher.fasl")
(#xbc375607cc967b3bcfc42911bc7c52c7 . "./code.idejs/ide-base.fasl")
(#xb6cc16e9e76ec699a10f700a2fc6de64 . "./code.idejs/ide.fasl")
(#xcf264678c8a3e1ee8bec0d3b2f37d41f . "./code.idejs/ide-trace.fasl")
(#xcd72c14f7049114ce7a45ed22c2fabc2 . "./code.idejs/ide-form.fasl")
(#xee1ca3dc0fb2c933f940696f30bf1510 . "./code.idejs/ide-find-definitions.fasl")
(#x01c8bc38a4f588437158080345949058 . "./code.idejs/ide-apropos.fasl")
(#x6ae75a185b44d5f2785410eac72a391e . "./code.idejs/ide-class-browser.fasl")
(#xccf7df23e5c6762cd189459a05357102 . "./code.idejs/ide-navigator.fasl")
(#x0d2ce359e9249d163a823df3b8ec59ea . "./code.idejs/ide-clipboard.fasl")
(#x64f9e2c42b48ea82d792abcc1fc416f6 . "./code.idejs/ide-acache.fasl")
(#x95768cf94693d9b041b2a6e56edc3ae3 . "./code.idejs/ide-keyshort.fasl")
(#xbe95f3ca0b4a4d8b4b507843d0eed599 . "./code.idejs/ide-package-list.fasl")
(#x982dee3d6acef130bbdd266b58bba46b . "./code.idejs/ide-dev.fasl")
(#xeb5b70ef6a4ced03becd92b82d3b0061 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
